@@ -3,13 +3,10 @@
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
-from xpra.server.auth.sys_auth_base import SysAuthenticator
+from xpra.server.auth.sys_auth_base import SysAuthenticator, init
 import os
 
 
-def init(opts):
-    pass
-
 class Authenticator(SysAuthenticator):
 
     def __init__(self, username):
