@@ -14,7 +14,8 @@ from xpra.log import Logger
 log = Logger("server", "gtk")
 
 from xpra.gtk_common.quit import (gtk_main_quit_really,
-                           gtk_main_quit_on_fatal_exceptions_enable)
+                           gtk_main_quit_on_fatal_exceptions_enable,
+                           gtk_main_quit_on_fatal_exceptions_disable)
 from xpra.server.server_base import ServerBase
 from xpra.gtk_common.gtk_util import get_gtk_version_info
 from xpra.gtk_common.gtk2common import gtk2main
@@ -40,8 +41,13 @@ class GTKServerBase(ServerBase):
         ### Set up keymap change notification:
         gtk.gdk.keymap_get_default().connect("keys-changed", self._keys_changed)
 
+    def signal_quit(self, signum, frame):
+        gtk_main_quit_on_fatal_exceptions_disable()
+        ServerBase.signal_quit(self, signum, frame)
+
     def do_quit(self):
         log("do_quit: calling gtk_main_quit_really")
+        gtk_main_quit_on_fatal_exceptions_disable()
         gtk_main_quit_really()
         log("do_quit: gtk_main_quit_really done")
 
@@ -94,9 +100,9 @@ class GTKServerBase(ServerBase):
         root_w, root_h = gtk.gdk.get_default_root_window().get_size()
         return root_w, root_h
 
-    def calculate_workarea(self):
-        root_w, root_h = gtk.gdk.get_default_root_window().get_size()
-        workarea = gtk.gdk.Rectangle(0, 0, root_w, root_h)
+    def calculate_workarea(self, maxw, maxh):
+        log("calculate_workarea(%s, %s)", maxw, maxh)
+        workarea = gtk.gdk.Rectangle(0, 0, maxw, maxh)
         for ss in self._server_sources.values():
             screen_sizes = ss.screen_sizes
             log("calculate_workarea() screen_sizes(%s)=%s", ss, screen_sizes)
@@ -115,7 +121,7 @@ class GTKServerBase(ServerBase):
         #sanity checks:
         if workarea.width==0 or workarea.height==0:
             log.warn("failed to calculate a common workarea - using the full display area")
-            workarea = gtk.gdk.Rectangle(0, 0, root_w, root_h)
+            workarea = gtk.gdk.Rectangle(0, 0, maxw, maxh)
         self.set_workarea(workarea)
 
     def set_workarea(self, workarea):
