@@ -18,6 +18,7 @@ log = Logger("proxy")
 
 from xpra.server.server_core import get_server_info, get_thread_info
 from xpra.scripts.server import deadly_signal
+from xpra.net import compression
 from xpra.net.compression import Compressed, compressed_wrapper
 from xpra.net.protocol import Protocol, get_network_caps
 from xpra.net.crypto import new_cipher_caps
@@ -155,6 +156,7 @@ class ProxyInstanceProcess(Process):
         self.server_protocol.large_packets.append("keymap-changed")
         self.server_protocol.large_packets.append("server-settings")
         self.server_protocol.set_compression_level(self.session_options.get("compression_level", 0))
+        self.server_protocol.enable_default_encoder()
 
         self.lost_windows = set()
         self.encode_queue = Queue()
@@ -210,7 +212,7 @@ class ProxyInstanceProcess(Process):
                     self.video_encoding_defs.setdefault(encoding, {}).setdefault(colorspace, []).append(spec_props)
                     encoder_types.add(spec.codec_type)
 
-        log("encoder types found: %s", encoder_types)
+        log("encoder types found: %s", tuple(encoder_types))
         #remove duplicates and use preferred order:
         order = PREFERRED_ENCODER_ORDER[:]
         for x in list(encoder_types):
@@ -263,6 +265,7 @@ class ProxyInstanceProcess(Process):
         protocol = Protocol(self, sc, self.process_control_packet)
         protocol.large_packets.append("info-response")
         self.potential_protocols.append(protocol)
+        protocol.enable_default_encoder()
         protocol.start()
         self.timeout_add(SOCKET_TIMEOUT*1000, self.verify_connection_accepted, protocol)
         return True
@@ -349,7 +352,7 @@ class ProxyInstanceProcess(Process):
         return d
 
     def filter_client_caps(self, caps):
-        fc = self.filter_caps(caps, ("cipher", "digest", "aliases", "compression", "lz4"))
+        fc = self.filter_caps(caps, ("cipher", "digest", "aliases", "compression", "lz4", "lz0", "zlib"))
         #update with options provided via config if any:
         fc.update(self.session_options)
         #add video proxies if any:
@@ -359,10 +362,7 @@ class ProxyInstanceProcess(Process):
         return fc
 
     def filter_server_caps(self, caps):
-        if caps.get("rencode", False):
-            self.server_protocol.enable_rencode()
-        elif caps.get("yaml", False):
-            self.server_protocol.enable_yaml()
+        self.server_protocol.enable_encoder_from_caps(caps)
         return self.filter_caps(caps, ("aliases", ))
 
     def filter_caps(self, caps, prefixes):
@@ -452,6 +452,12 @@ class ProxyInstanceProcess(Process):
         if packet_type==Protocol.CONNECTION_LOST:
             self.stop("client connection lost", proto)
             return
+        elif packet_type=="disconnect":
+            log("got disconnect from client: %s", packet[1])
+            if self.exit:
+                self.client_protocol.close()
+            else:
+                self.stop("disconnect from client: %s" % packet[1])
         elif packet_type=="set_deflate":
             #echo it back to the client:
             self.client_packets.put(packet)
@@ -480,6 +486,12 @@ class ProxyInstanceProcess(Process):
         if packet_type==Protocol.CONNECTION_LOST:
             self.stop("server connection lost", proto)
             return
+        elif packet_type=="disconnect":
+            log("got disconnect from server: %s", packet[1])
+            if self.exit:
+                self.server_protocol.close()
+            else:
+                self.stop("disconnect from server: %s" % packet[1])
         elif packet_type=="hello":
             c = typedict(packet[1])
             maxw, maxh = c.intpair("max_desktop_size", (4096, 4096))
@@ -521,9 +533,9 @@ class ProxyInstanceProcess(Process):
                     packet[8] = str(pixels)
                 else:
                     #FIXME: this is ugly and not generic!
-                    zlib = self.caps.get("zlib", True)
-                    lz4 = self.caps.get("lz4", False)
-                    lzo = self.caps.get("lzo", False)
+                    zlib = compression.use_zlib and self.caps.get("zlib", True) 
+                    lz4 = compression.use_lz4 and self.caps.get("lz4", False) 
+                    lzo = compression.use_lzo and self.caps.get("lzo", False)
                     if zlib or lz4 or lzo:
                         packet[8] = compressed_wrapper("cursor", pixels, zlib=zlib, lz4=lz4, lzo=lzo, can_inline=False)
                     else:
@@ -578,12 +590,6 @@ class ProxyInstanceProcess(Process):
         if encoding=="mmap":
             return True
 
-        if not self.video_encoder_types or not client_options or not client_options.get("proxy", False):
-            #ensure we don't try to re-compress the pixel data in the network layer:
-            #(re-add the "compressed" marker that gets lost when we re-assemble packets)
-            packet[7] = Compressed("%s pixels" % encoding, packet[7])
-            return True
-
         #we have a proxy video packet:
         rgb_format = client_options.get("rgb_format", "")
         log("proxy draw: client_options=%s", client_options)
@@ -596,18 +602,39 @@ class ProxyInstanceProcess(Process):
             log("returning %s bytes from %s", len(compressed_data), len(pixels))
             return (wid not in self.lost_windows)
 
-        def passthrough():
-            #passthrough as plain RGB:
-            newdata = bytearray(pixels)
-            #force alpha (and assume BGRX..) for now:
-            for i in range(len(pixels)/4):
-                newdata[i*4+3] = chr(255)
-            packet[9] = client_options.get("rowstride", 0)
-            return send_updated("rgb32", str(newdata), {"rgb_format" : rgb_format})
+        def passthrough(strip_alpha=True):
+            log("proxy draw: %s passthrough (rowstride: %s vs %s, strip alpha=%s)", rgb_format, rowstride, client_options.get("rowstride", 0), strip_alpha)
+            if strip_alpha:
+                #passthrough as plain RGB:
+                Xindex = rgb_format.upper().find("X")
+                if Xindex>=0 and len(rgb_format)==4:
+                    #force clear alpha (which may be garbage):
+                    newdata = bytearray(pixels)
+                    for i in range(len(pixels)/4):
+                        newdata[i*4+Xindex] = chr(255)
+                    packet[9] = client_options.get("rowstride", 0)
+                    cdata = bytes(newdata)
+                else:
+                    cdata = pixels
+                new_client_options = {"rgb_format" : rgb_format}
+            else:
+                #preserve
+                cdata = pixels
+                new_client_options = client_options
+            wrapped = Compressed("%s pixels" % encoding, cdata)
+            #FIXME: we should not assume that rgb32 is supported here...
+            #(we may have to convert to rgb24..)
+            return send_updated("rgb32", wrapped, new_client_options)
 
-        if PASSTHROUGH:
-            passthrough()
-            return
+        proxy_video = client_options.get("proxy", False)
+        if PASSTHROUGH and (encoding in ("rgb32", "rgb24") or proxy_video):
+            #we are dealing with rgb data, so we can pass it through:
+            return passthrough(proxy_video)
+        elif not self.video_encoder_types or not client_options or not proxy_video:
+            #ensure we don't try to re-compress the pixel data in the network layer:
+            #(re-add the "compressed" marker that gets lost when we re-assemble packets)
+            packet[7] = Compressed("%s pixels" % encoding, packet[7])
+            return True
 
         #video encoding: find existing encoder
         ve = self.video_encoders.get(wid)
@@ -648,8 +675,7 @@ class ProxyInstanceProcess(Process):
                 from xpra.server.picture_encode import PIL_encode, PIL, warn_encoding_once
                 if PIL is None:
                     warn_encoding_once("no-video-no-PIL", "no video encoder found for rgb format %s, sending as plain RGB!" % rgb_format)
-                    passthrough()
-                    return
+                    return passthrough()
                 log("no video encoder available: sending as jpeg")
                 coding, compressed_data, client_options, _, _, _, _ = PIL_encode("jpeg", image, quality, speed, False)
                 return send_updated(coding, compressed_data, client_options)
