@@ -677,7 +677,7 @@ class ServerBase(ServerCore):
                 "client_window_properties",
                 "sound_sequence", "notify-startup-complete", "suspend-resume",
                 "encoding.generic", "encoding.strict_control",
-                "sound.server_driven",
+                "sound.server_driven", "sound.ogg-latency-fix",
                 "command_request",
                 "event_request", "server-events",
                 "sound.eos-sequence")
